==> eta-kisit_0.6.4.tar.xz: eta-kisit-0.6.4/src/managers/ApplicationManager.py <==
from gi.repository import Gio
from pathlib import Path
import os
import json
import managers.FileRestrictionManager as FileRestrictionManager
import shutil


CONFIG_DIR = Path("/var/lib/eta/eta-kisit/")
INSTALLED_APPLICATIONS_PATH = os.path.join(CONFIG_DIR, "installed_applications.json")
ALWAYS_ALLOWED_APPLICATIONS = ["tr.org.pardus.eta-exit.desktop", "eta-r.desktop"]
ALWAYS_ALLOWED_EXECUTABLES = ["libreoffice"]
UNPRIVILEGED_USER = "ogrenci"
UNPRIVILEGED_USER_APPLICATIONS_DIR = "/home/{}/.local/share/applications".format(
    UNPRIVILEGED_USER
)


def get_all_applications():
    apps = Gio.AppInfo.get_all()
    # Filter only visible applications
    apps = filter(lambda a: not a.get_nodisplay(), apps)
    apps = sorted(apps, key=lambda a: a.get_name())  # Sort alphabetically

    return list(apps)


def save_as_json_file(object, filepath=INSTALLED_APPLICATIONS_PATH):
    try:
        # First create the directories
        CONFIG_DIR.mkdir(mode=0o660, parents=True, exist_ok=True)

        # Then create the file
        with open(filepath, "w", encoding="utf-8") as f:
            json.dump(
                object,
                f,
                ensure_ascii=False,
                indent=4,
                sort_keys=True,
            )
    except PermissionError:
        print("Not enough permissions to create:{}".format(INSTALLED_APPLICATIONS_PATH))
        return


def save_all_applications():
    applist = get_all_applications()

    json_object = {}

    for app in applist:
        json_object[app.get_id()] = {
            "name": app.get_name(),
            "bin": app.get_executable(),
            "cmdline": app.get_commandline(),
        }

    save_as_json_file(json_object)


# APPLICATION RESTRICTIONS:
def find_local_application(application_id):
    local_desktop_file = UNPRIVILEGED_USER_APPLICATIONS_DIR + "/" + application_id
    if os.path.exists(local_desktop_file):
        return local_desktop_file
    return None


def restrict_application(application_id):
    if application_id in ALWAYS_ALLOWED_APPLICATIONS:
        print(application_id, " is always allowed. SKIPPING.")
        return

    local_desktop_file = find_local_application(application_id)
    if local_desktop_file:
        print("Local application found:", local_desktop_file)
        FileRestrictionManager.restrict_desktop_file(local_desktop_file)

    try:
        app = Gio.DesktopAppInfo.new(application_id)
    except TypeError:
        print("Application not found:", application_id)
        return

    desktop_file_path = app.get_filename()
    executable_file_path = app.get_executable()
    print("Restricted:\t", desktop_file_path)
    print("  executable_file_path:\t", executable_file_path)
    print("  cmdline:\t\t", app.get_commandline())

    # Restrict desktopfile
    FileRestrictionManager.restrict_desktop_file(desktop_file_path)

    # Restrict executable
    if executable_file_path in ALWAYS_ALLOWED_EXECUTABLES:
        print(executable_file_path, " executable is always allowed. SKIPPING.")
        return

    if (
        "flatpak" in executable_file_path
        or "snap" in executable_file_path
        or "/bin/sh" in executable_file_path
        or "/bin/bash" in executable_file_path
        or "sh" == executable_file_path
        or "bash" == executable_file_path
    ):
        print(
            "Not restricting executable because flatpak/snap/bash/sh program:",
            executable_file_path,
        )
        return
    else:
        # Don't restrict Chrom(e|ium) links:
        if "chrom" in executable_file_path and "chrom" not in application_id:
            return

        if executable_file_path.startswith("/"):
            # absolute path, restrict it directly
            FileRestrictionManager.restrict_bin_file(executable_file_path)
        else:
            absolute_path = shutil.which(executable_file_path)
            FileRestrictionManager.restrict_bin_file(absolute_path)


def unrestrict_application(application_id):
    local_desktop_file = find_local_application(application_id)
    if local_desktop_file:
        print("Local application found:", local_desktop_file)
        FileRestrictionManager.unrestrict_local_desktop_file(local_desktop_file)

    try:
        app = Gio.DesktopAppInfo.new(application_id)
    except TypeError:
        print("Application not found:", application_id)
        return

    desktop_file_path = app.get_filename()
    executable_file_path = app.get_executable()

    print("Unrestricted:\t", desktop_file_path)
    print("  executable_file_path:\t", executable_file_path)
    print("  cmdline:\t\t", app.get_commandline())

    # Unrestrict desktopfile
    FileRestrictionManager.unrestrict_desktop_file(desktop_file_path)

    # Unrestrict executable
    if (
        "flatpak" in executable_file_path
        or "snap" in executable_file_path
        or "/bin/sh" in executable_file_path
        or "/bin/bash" in executable_file_path
        or "sh" == executable_file_path
        or "bash" == executable_file_path
    ):
        return
    else:
        # Don't unrestrict Chrome links:
        if "chrom" in executable_file_path and "chrom" not in application_id:
            return

        if executable_file_path.startswith("/"):
            # absolute path, restrict it directly
            FileRestrictionManager.unrestrict_bin_file(executable_file_path)
        else:
            absolute_path = shutil.which(executable_file_path)
            FileRestrictionManager.unrestrict_bin_file(absolute_path)

==> eta-kisit_0.8.0.tar.xz: eta-kisit-0.8.0/src/managers/ApplicationManager.py <==
from gi.repository import Gio
from pathlib import Path
import os
import json
import managers.FileRestrictionManager as FileRestrictionManager
import ETAKisitActivator
import shutil


CONFIG_DIR = Path("/var/lib/eta/eta-kisit/")
INSTALLED_APPLICATIONS_PATH = os.path.join(CONFIG_DIR, "installed_applications.json")
ALWAYS_ALLOWED_APPLICATIONS = [
    # Restart and Exit buttons
    "tr.org.pardus.eta-exit.desktop",
    "eta-r.desktop",
    # Keyboard
    "eta-keyboard.desktop",
    "eta-keyboard-autostart.desktop",
]
ALWAYS_ALLOWED_EXECUTABLES = ["libreoffice"]
UNPRIVILEGED_USER = "ogrenci"
UNPRIVILEGED_USER_APPLICATIONS_DIR = "/home/{}/.local/share/applications".format(
    UNPRIVILEGED_USER
)


def get_all_applications():
    apps = Gio.AppInfo.get_all()
    # Filter only visible applications
    apps = filter(lambda a: not a.get_nodisplay(), apps)
    apps = sorted(apps, key=lambda a: a.get_name())  # Sort alphabetically

    return list(apps)


def save_as_json_file(object, filepath=INSTALLED_APPLICATIONS_PATH):
    try:
        # Then create the file
        with open(filepath, "w", encoding="utf-8") as f:
            json.dump(
                object,
                f,
                ensure_ascii=False,
                indent=4,
                sort_keys=True,
            )
    except PermissionError:
        process = ETAKisitActivator.run_activator(["--fix-permissions"])

        if process.returncode == 0:
            save_as_json_file(filepath)
        else:
            print(
                "Can't change file permissions, are you sure you are root or in floppy group?"
            )


def save_all_applications():
    applist = get_all_applications()

    json_object = {}

    for app in applist:
        json_object[app.get_id()] = {
            "name": app.get_name(),
            "bin": app.get_executable(),
            "cmdline": app.get_commandline(),
        }

    save_as_json_file(json_object)


# APPLICATION RESTRICTIONS:
def find_local_application(application_id):
    local_desktop_file = UNPRIVILEGED_USER_APPLICATIONS_DIR + "/" + application_id
    if os.path.exists(local_desktop_file):
        return local_desktop_file
    return None


def restrict_application(application_id):
    if application_id in ALWAYS_ALLOWED_APPLICATIONS:
        print(application_id, " is always allowed. SKIPPING.")
        return

    local_desktop_file = find_local_application(application_id)
    if local_desktop_file:
        print("Local application found:", local_desktop_file)
        FileRestrictionManager.restrict_desktop_file(local_desktop_file)

    try:
        app = Gio.DesktopAppInfo.new(application_id)
    except TypeError:
        print("Application not found:", application_id)
        return

    desktop_file_path = app.get_filename()
    executable_file_path = app.get_executable()
    print("Restricted:\t", desktop_file_path)
    print("  executable_file_path:\t", executable_file_path)
    print("  cmdline:\t\t", app.get_commandline())

    # Restrict desktopfile
    FileRestrictionManager.restrict_desktop_file(desktop_file_path)

    # Restrict executable
    if executable_file_path in ALWAYS_ALLOWED_EXECUTABLES:
        print(executable_file_path, " executable is always allowed. SKIPPING.")
        return

    if (
        "flatpak" in executable_file_path
        or "snap" in executable_file_path
        or "/bin/sh" in executable_file_path
        or "/bin/bash" in executable_file_path
        or "sh" == executable_file_path
        or "bash" == executable_file_path
    ):
        print(
            "Not restricting executable because flatpak/snap/bash/sh program:",
            executable_file_path,
        )
        return

    # Don't restrict Chrom(e|ium) links:
    if "chrom" in executable_file_path and "chrom" not in application_id:
        return

    if executable_file_path.startswith("/"):
        # absolute path, restrict it directly
        FileRestrictionManager.restrict_bin_file(executable_file_path)
    else:
        absolute_path = shutil.which(executable_file_path)
        FileRestrictionManager.restrict_bin_file(absolute_path)


def unrestrict_application(application_id):
    local_desktop_file = find_local_application(application_id)
    if local_desktop_file:
        print("Local application found:", local_desktop_file)
        FileRestrictionManager.unrestrict_local_desktop_file(local_desktop_file)

    try:
        app = Gio.DesktopAppInfo.new(application_id)
    except TypeError:
        print("Application not found:", application_id)
        return

    desktop_file_path = app.get_filename()
    executable_file_path = app.get_executable()

    print("Unrestricted:\t", desktop_file_path)
    print("  executable_file_path:\t", executable_file_path)
    print("  cmdline:\t\t", app.get_commandline())

    # Unrestrict desktopfile
    FileRestrictionManager.unrestrict_desktop_file(desktop_file_path)

    # Unrestrict executable
    if (
        "flatpak" in executable_file_path
        or "snap" in executable_file_path
        or "/bin/sh" in executable_file_path
        or "/bin/bash" in executable_file_path
        or "sh" == executable_file_path
        or "bash" == executable_file_path
    ):
        return
    else:
        # Don't unrestrict Chrome links:
        if "chrom" in executable_file_path and "chrom" not in application_id:
            return

        if executable_file_path.startswith("/"):
            # absolute path, restrict it directly
            FileRestrictionManager.unrestrict_bin_file(executable_file_path)
        else:
            absolute_path = shutil.which(executable_file_path)
            FileRestrictionManager.unrestrict_bin_file(absolute_path)
